
const { ccclass, property } = cc._decorator;
@ccclass
export default class CameraComponent extends cc.Component {
    @property(cc.Camera)
    camera: cc.Camera = null;

    @property(cc.Node)
    target: cc.Node = null;

    @property(cc.Node)
    background: cc.Node = null;


    followX: number = 0;
    followY: number = 200;
    centerAtStart: boolean = false;
    smoothFollow: boolean = true;
    startFollow: boolean = false;
    minFollowDist: number = 200;
    followRatio: number = 0.1;
    visibleSize: cc.Size;
    upHeightRatio: number = 2;
    maxUpHeight: number;

    latePosition: cc.Vec2;
    onEnable() {
        console.log("+++++++++onEnable++++++++");
        cc.director.getCollisionManager().enabled = true;
        
    }
    onDisable() {
        console.log("+++++++++onDisable++++++++");
        cc.director.getCollisionManager().enabled = false;
    }

    onLoad() {
        console.log("+++++++this.camera.targets:",this.camera);
        this.visibleSize = cc.view.getVisibleSize();
        this.maxUpHeight = this.visibleSize.height / this.upHeightRatio;
    }

    update(dt: any) {

        let targetPos = this.target.parent.convertToWorldSpaceAR(this.target.position);
        if (targetPos.y > this.maxUpHeight && Math.abs(this.target.y - this.node.y) >= this.followY && this.node.y >= 0) {
            //console.log("++++++++++++targetPos.y:", targetPos.y, "  this.node.y:", this.node.y);
            this.startFollow = true;
        }

        if (this.startFollow) {
            let cameraPos = this.node.position;
            //console.log("++++++++++++targetPos.y:", targetPos.y, "  cameraPos.y:", cameraPos.y);
            var cameraNewPos = cameraPos.lerp(this.target.position, this.followRatio);
            if (cameraNewPos.y <= 0) {
                return;
            }
            if (null != this.latePosition && this.latePosition.y > cameraNewPos.y) {
                return;
            }
            this.node.position = cameraNewPos;
            this.latePosition = cameraNewPos;
            let distance = Math.abs(this.node.position.sub(targetPos).mag());
            if (distance <= this.minFollowDist) {
                this.startFollow = false;
            }
        }
    }

}