import { ImageService } from "../service/ImageService";
import { AudioService } from "../service/AudioService";

const { ccclass, property } = cc._decorator;

@ccclass
export default class MainComponent extends cc.Component {

    @property(cc.Sprite)
    gameVoiceBtn: cc.Sprite = null;

    @property(cc.Sprite)
    gameMusicBtn: cc.Sprite = null;

    @property(cc.Sprite)
    gameStartBtn: cc.Sprite = null;


    bgMusicId: number;

    onLoad() {
        this.gameVoiceBtn.node.on(cc.Node.EventType.TOUCH_START, this.onGameVoice, this);
        this.gameMusicBtn.node.on(cc.Node.EventType.TOUCH_START, this.onGameMusic, this);
        this.gameStartBtn.node.on(cc.Node.EventType.TOUCH_START, this.onStart, this);

        this.loadAtlas();

        this.loadAudios();

        this.playBgMusic();

        this.onBtnAnimal();

        this.loadScence();
    }

    private loadScence(){
        cc.director.preloadScene("Main");
        cc.director.preloadScene("Game");
    }

    private loadAtlas() {
        ImageService.loadAtlas("images/atlas");
    }

    private loadAudios() {
        AudioService.loadResDir("audios",this.playBgMusic.bind(this));
    }

    onStart() {
        cc.director.loadScene("Game");
    }

    onGameVoice(event) {
        var frameName = this.gameVoiceBtn.spriteFrame.name;
        if (frameName == "voice_open") {
            let spriteFrame: cc.SpriteFrame = ImageService.get("checkbox_voice_close");
            this.gameVoiceBtn.spriteFrame = spriteFrame;
        } else {
            let spriteFrame: cc.SpriteFrame = ImageService.get("checkbox_voice_open");
            this.gameVoiceBtn.spriteFrame = spriteFrame;
        }
    }

    onGameMusic(event) {
       
        var frameName = this.gameMusicBtn.spriteFrame.name;
        if (frameName == "music_open") {
            let spriteFrame: cc.SpriteFrame = ImageService.get("checkbox_music_close");
            this.gameMusicBtn.spriteFrame = spriteFrame;
            this.stopBgMusic();
        } else {
            let spriteFrame: cc.SpriteFrame = ImageService.get("checkbox_music_open");
            this.gameMusicBtn.spriteFrame = spriteFrame;
            this.playBgMusic();
        }

    }

    private newActionInterval() {
        let actionOne = cc.scaleTo(0.1, 1.2, 1.2);
        let actionTwo = cc.scaleTo(0.1, 1, 1);
        return cc.sequence(actionOne, actionTwo);
    }


    private playBgMusic() {
        let clip: cc.AudioClip = AudioService.get("bg");
        if (null != clip) {
            this.bgMusicId = cc.audioEngine.play(clip, false, 0.5);
        }
    }

    private stopBgMusic() {
        cc.audioEngine.stop(this.bgMusicId);
    }

    private onBtnAnimal(){
        let gameMusicAction = this.newActionInterval();
        this.gameMusicBtn.node.runAction(gameMusicAction);

        let gameVoiceAction = this.newActionInterval();
        this.gameVoiceBtn.node.runAction(gameVoiceAction);

        this.onStartAnimal();
    }

    public onStartAnimal(){
        let actionOne = cc.scaleTo(1, 0.8, 0.8);
        let actionTwo = cc.scaleTo(1, 1, 1);
        let seqAction  = cc.sequence(actionOne,actionTwo);
        let repeatAction = cc.repeatForever (seqAction)
        this.gameStartBtn.node.runAction(repeatAction);
    }

}
