import { ProtocolResponse } from "../proto/response/ProtocolResponse";
import { Util } from "./Util";

export class Http {
    static connected: boolean = true;

    public static async post(url: string, params?: any, options?: any): Promise<ProtocolResponse> {
        return this.service(url, "post", params, options);
    }

    public static async get(url: string, params: object, options?: any): Promise<ProtocolResponse> {
        return this.service(url, "get", params, options);
    }

    private static service(url: string, method: 'post' | 'get', params: object, options: any): Promise<ProtocolResponse> {
        options = this.settings(url, params, options);
        options.method = method;
        let that = this;
        console.log("+++++++http url:", url, " method:", method, " request:" + JSON.stringify(options.data))
        let promise = new Promise<ProtocolResponse>(resolve => {
            options.complete = function complete(res: any) {
                console.log("+++++++http url:", url, " method:", method, " response:" + JSON.stringify(res.data))
                let response = null;
                if (res.statusCode === 200) {
                    response = that.toSuccessResponse(res.data);

                } else {
                    response = that.toFailResponse();
                }
                resolve(response);
            }
            wx.request(options);
        });
        return promise;
    }


    private static toSuccessResponse(data: any): ProtocolResponse {
        let that = this;
        let response = Object.assign(new ProtocolResponse(), data);
        return response;
    }

    private static toFailResponse(): ProtocolResponse {
        let response = new ProtocolResponse();
        response.code = -1;
        response.msg = "";
        response.result = "";
        return response;
    }

    private static settings(url: string, params?: any, options?: any): any {
        let tmpSetting: any = {};

        if (url) {
            tmpSetting.url = url;
        }

        if (options) {
            for (var key in options) {
                tmpSetting[key] = options[key];
            }
        }

        if (params) {
            tmpSetting.data = params;
        }
        tmpSetting.header = {
            'content-type': 'application/x-www-form-urlencoded'
        };

        return tmpSetting;
    }
    private static buildParams(data) {

        var _type = typeof (data);

        if (!data || _type == 'string') {
            return data;
        }

        if (_type == 'object') {
            var params = '';
            for (var key in data) {
                params += key + '=' + data[key] + '&';
            }
            return params;
        }

        return data;

    }

    private static checkNetwork(res) {
        if (res == null || undefined == res.statusCode || null == res.statusCode) {
            Mini.errorShowToast({ title: "网络加载失败" });
            return false;
        }
    }

    private static openNetworkListen() {
        var that = this;
        //添加网络状态监听
        wx.onNetworkStatusChange(function (status) {
            that.connected = status.isConnected;
        });
    }

    private static isConnected() {
        var that = this;
        console.log("network.isConnected:", that.connected);
        if (!that.connected) {
            Mini.errorShowToast({ title: "网络加载失败" });
            return false;
        }
        return true;
    }

}

